@@ -39,6 +39,9 @@ const Ci = Components.interfaces;
 
 Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
 
+const APPLICATION_CID = Components.ID("f265021a-7f1d-4b4b-bdc6-9aedca4d8f13");
+const APPLICATION_CONTRACTID = "@mozilla.org/steel/application;1";
+
 //=================================================
 // Factory - Treat Application as a singleton
 // XXX This is required, because we're registered for the 'JavaScript global
@@ -62,20 +65,22 @@ function Application() {
   this.initToolkitHelpers();
 }
 
+
 Application.prototype = {
-  classID:          Components.ID("f265021a-7f1d-4b4b-bdc6-9aedca4d8f13"),
+  classID: APPLICATION_CID,
 
   // redefine the default factory for XPCOMUtils
   _xpcom_factory: ApplicationFactory,
 
   // for nsISupports
-  QueryInterface : XPCOMUtils.generateQI([Ci.steelIApplication, Ci.extIApplication, Ci.nsIObserver, Ci.nsIClassInfo]),
+  QueryInterface : XPCOMUtils.generateQI([Ci.steelIApplication, Ci.extIApplication, Ci.nsIObserver]),
 
-  getInterfaces : function app_gi(aCount) {
-    let interfaces = [Ci.steelIApplication, Ci.extIApplication, Ci.nsIObserver, Ci.nsIClassInfo];
-    aCount.value = interfaces.length;
-    return interfaces;
-  },
+  classInfo: XPCOMUtils.generateCI({classID: APPLICATION_CID,
+				    contractID: APPLICATION_CONTRACTID,
+				    interfaces: [Ci.steelIApplication,
+						 Ci.extIApplication,
+						 Ci.nsIObserver],
+				    flags: Ci.nsIClassInfo.SINGLETON}),
 
   // for steelIApplication
   platformIsMac: "nsILocalFileMac" in Components.interfaces
@@ -639,19 +644,9 @@ extApplication.prototype = {
     this._registered = {"unload": true};
   },
 
-  // for nsIClassInfo
-  flags : Ci.nsIClassInfo.SINGLETON,
-  implementationLanguage : Ci.nsIProgrammingLanguage.JAVASCRIPT,
-
-  getInterfaces : function app_gi(aCount) {
-    var interfaces = [Ci.extIApplication, Ci.nsIObserver, Ci.nsIClassInfo];
-    aCount.value = interfaces.length;
-    return interfaces;
-  },
-
-  getHelperForLanguage : function app_ghfl(aCount) {
-    return null;
-  },
+  classInfo: XPCOMUtils.generateCI({interfaces: [Ci.extIApplication,
+                                                 Ci.nsIObserver],
+                                    flags: Ci.nsIClassInfo.SINGLETON}),
 
   // extIApplication
   get id() {
@@ -768,7 +763,7 @@ extApplication.prototype = {
 
   QueryInterface : XPCOMUtils.generateQI([Ci.extIApplication, Ci.nsISupportsWeakReference])
 };
-//@line 85 "/export/home/mozilla/packages/BUILD/SFWthunderbird/comm-release/mail/steel/steelApplication.js"
+//@line 90 "/export/home/mozilla/packages/BUILD/SFWthunderbird/comm-release/mail/steel/steelApplication.js"
 
 Application.prototype.__proto__ = extApplication.prototype;
 
